.. _httpx_transport:

HTTPXTransport
==============

The HTTPXTransport is a sync transport using the `httpx`_ library
and allows you to send GraphQL queries using the HTTP protocol.

Reference: :class:`gql.transport.httpx.HTTPXTransport`

.. literalinclude:: ../code_examples/httpx_sync.py

.. _httpx: https://www.python-httpx.org
